# TODO List

This document shows the product roadmap for kb as a point-in-time.

No guarantees can be given that a specific feature will be included in a release, nor can any definitive timeframe for any release be given.

# Next Major Release 1.0:

- The create kb database queries should be abstracted
- Find a way to load custom templates by artifact (maybe store it in db?) (DONE)
- Distributed API to use kb (kb as a service) (alshapton is working on this
- Abstract kb database login
- Update Instructions 0.x -> 1.0
- Docker fixes - Alpine Linux/Vim/Nano/Python3 + dependencies + kb


# Later Releases:

- Include security checking and auto updates (dependabot)
- Consider future of recent.hist file
- Full test suite
- Find a way to include complex artifacts
- Write installation procedure for Windows (choco and scoop)
- Add mobile application
- Web application
- SQLite change 
- Fix notepad (Windows) hell with automatic extensions...
- Executable standalone - Pyinstaller
